import React, { useContext, useCallback } from 'react';
import { Box, Segment, Text } from '../../elements';
import { Loader } from '../../modules';
import { useAsyncComponent } from '../../../hooks';
import { Menu, MenuItem } from '../Menu';
import { DashboardContext } from './context';
const WidgetContent = ({ config }) => {
    const Component = useAsyncComponent(config.as);
    const props = {};
    if (config.as === 'Button') {
        switch (config.action) {
            case 'LOG':
                props.onClick = console.log;
                break;
        }
    }
    return (React.createElement(React.Suspense, { fallback: React.createElement(Loader, { active: true }) },
        React.createElement(Component, Object.assign({}, props), config.content)));
};
export const Widget = ({ config }) => {
    const { color } = useContext(DashboardContext);
    const renderMenu = useCallback(() => {
        const showMenu = !!config.title;
        if (!showMenu) {
            return null;
        }
        return (React.createElement(Menu, null, config.title && (React.createElement(MenuItem, null,
            React.createElement(Text, { as: "span", color: color }, config.title)))));
    }, [config, color]);
    return (React.createElement(Box, { size: config.size, padded: true, stretched: true },
        React.createElement(Segment, { raised: true },
            renderMenu(),
            React.createElement(React.Suspense, { fallback: React.createElement(Loader, { active: true }) },
                React.createElement(WidgetContent, { config: config })))));
};
