import { Fragment, useMemo, lazy } from 'react';
/**
 * Async component loading for use with Dashboard.
 *
 * Should be used with component wrapped in `React.Suspense`
 *
 * @example
 * ```
 * const AsyncHeader = () => {
 *  const Header = useAsyncComponent('Header');
 *
 *  return <Header>Hello world!</Header>
 * }
 *
 * ...
 *
 * <React.Suspense fallback={<Loader active />}>
 *   <AsyncHeader />
 * </React.Suspense>
 * ```
 */
export const useAsyncComponent = (type) => {
    return useMemo(() => {
        switch (type) {
            case 'Button':
                return lazy(() => import('../components/inputs/Button/Button'));
            case 'Header':
                return lazy(() => import('../components/elements/Text/Header'));
            case 'Text':
                return lazy(() => import('../components/elements/Text/Text'));
            default:
                return Fragment;
        }
    }, [type]);
};
