import { text, primary, secondary, raised } from './color';
import { createTheme } from '../theme';
const theme = createTheme({
    greyscale: {
        medium: '#ddd',
    },
});
describe('raised', () => {
    it('Empty style', () => {
        const res = raised({ theme });
        expect(res).toBeFalsy();
    });
    it('Generates raised style', () => {
        const res = raised({
            theme,
            raised: true,
        });
        expect(res).toBeTruthy();
        expect(res.boxShadow).toBe('0 0px 2px 0  #ddd, 0 2px 4px 0  #ddd');
    });
});
describe('text', () => {
    it('Empty style', () => {
        const res = text({ theme });
        expect(res).toBeFalsy();
    });
    it('Generates coloured style', () => {
        const res = text({ theme, color: 'red' });
        expect(res).toBeTruthy();
        expect(res.color).toBe(theme.colors.red.default);
    });
});
describe('primary', () => {
    it('Generates style', () => {
        const res = primary({ theme });
        expect(res).toBeTruthy();
        expect(res.backgroundColor).toBe(theme.colors.primary.default);
    });
    it('Generates coloured style', () => {
        const res = primary({ theme, color: 'red' });
        expect(res).toBeTruthy();
        expect(res.backgroundColor).toBe(theme.colors.red.default);
    });
});
describe('secondary', () => {
    it('Generates style', () => {
        const res = secondary({ theme });
        expect(res).toBeTruthy();
        expect(res.backgroundColor).toBe('transparent');
    });
    it('Generates coloured style', () => {
        const res = secondary({ theme, color: 'red' });
        expect(res).toBeTruthy();
        expect(res.color).toBe(theme.colors.red.dark);
    });
});
