import { createTheme } from '../theme';
import { flexbox, alignRow, alignColumn } from './flex';
const theme = createTheme({
    breakpoints: {
        md: 100,
        lg: 200,
        xl: 300,
    },
});
function checkBreakpoints(res, expected) {
    expect(res['@media only screen and (max-width: 99px)']).toEqual({
        flexBasis: expected[0],
    });
    expect(res['@media only screen and (max-width: 199px) and (min-width: 100px)']).toEqual({
        flexBasis: expected[1],
    });
    expect(res['@media only screen and (max-width: 299px) and (min-width: 200px)']).toEqual({
        flexBasis: expected[2],
    });
    expect(res['@media only screen and (min-width: 300px)']).toEqual({
        flexBasis: expected[3],
    });
}
describe('flexbox', () => {
    it('Empty style', () => {
        const res = flexbox({ theme });
        expect(res).toBeFalsy();
    });
    it('Accept one value', () => {
        const res = flexbox({ theme, size: 0.5 });
        expect(res).toBeTruthy();
        checkBreakpoints(res, ['100%', '50%', '50%', '50%']);
    });
    it('Accept two values', () => {
        const res = flexbox({ theme, size: [0.5, 0.6] });
        expect(res).toBeTruthy();
        checkBreakpoints(res, ['50%', '60%', '60%', '60%']);
    });
    it('Accept all values', () => {
        const res = flexbox({ theme, size: [0.5, 0.6, 0.7, 0.8] });
        expect(res).toBeTruthy();
        checkBreakpoints(res, ['50%', '60%', '70%', '80%']);
    });
    it('Force minimum value', () => {
        const res = flexbox({ theme, size: -1 });
        expect(res).toBeTruthy();
        checkBreakpoints(res, ['100%', '0%', '0%', '0%']);
    });
    it('Force maximum value', () => {
        const res = flexbox({ theme, size: 2 });
        expect(res).toBeTruthy();
        checkBreakpoints(res, ['100%', '100%', '100%', '100%']);
    });
});
describe('alignRow', () => {
    it('Default', () => {
        const res = alignRow({});
        expect(res).toBeTruthy();
        expect(res).toEqual({ width: '100%' });
    });
    it('Set vertical align', () => {
        const res = alignRow({ verticalAlign: 'center' });
        expect(res).toBeTruthy();
        expect(res.alignItems).toBe('center');
    });
    it('Set floated', () => {
        const res = alignRow({ floated: 'left' });
        expect(res).toBeTruthy();
        expect(res.justifyContent).toBe('flex-start');
        expect(res.marginRight).toBe('auto');
    });
    it('Set centered', () => {
        const res = alignRow({ centered: true });
        expect(res).toBeTruthy();
        expect(res.justifyContent).toBe('center');
    });
});
describe('alignColumn', () => {
    it('Empty', () => {
        const res = alignColumn({ verticalAlign: 'center' });
        expect(res).toBeTruthy();
        expect(res.justifyContent).toBe('center');
    });
    it('Set floated', () => {
        const res = alignColumn({ floated: 'left' });
        expect(res).toBeTruthy();
        expect(res.alignItems).toBe('flex-start');
        expect(res.marginRight).toBe('auto');
    });
    it('Set centered', () => {
        const res = alignColumn({ centered: true });
        expect(res).toBeTruthy();
        expect(res.alignItems).toBe('center');
    });
});
